require_relative 'test_helper'
require 'stringio'

class RailsTest < MiniTest::Unit::TestCase
  def self.before_suite
    Docker::Rails.build(TEST_APP_PATH)
    @@app_name = TEST_APP_PATH.match(/(\/(\w+))?$/)[2]
    @@server_name = "rails-server-#{@@app_name}"
    @@container = Docker::Rails.run_server(TEST_APP_PATH)
  end

  def self.after_suite
    # @@container.remove!
  end

  def test_docker_can_build_a_rails_app_image
    assert_match /jphager2\/rails-#{@@app_name}/, `docker images`
  end

  def test_docker_can_start_a_rails_app_container
    assert_equal @@server_name, @@container.name 
    assert_includes Docker.containers(:running), @@container 
  end

  def test_docker_run_rails_app_starts_postgres 
    assert Docker.containers(:running).any? { |c| c.name == 'db' }
  end

  def test_docker_can_start_a_rails_console_session
    TestHelper.assert_match_stderr(/rails-console-app/, self) do
      Docker::Rails.run_console(TEST_APP_PATH)
    end 
  end

  def test_docker_can_run_a_command_in_a_rails_app
    container = Docker::Rails.run(TEST_APP_PATH, "", "ls")
    assert_match /Gemfile/, container.logs
    container.remove!
  end
end
