require_relative 'test_helper'

class ImagesTest < MiniTest::Unit::TestCase
  def self.before_suite
  end

  def self.after_suite
  end

  def test_images_returns_a_collection_of_images
    Docker.images.each do |image|
      assert_instance_of Docker::Image, image 
    end
  end

  def test_images_returns_a_collection_of_tags
    Docker.images(:tag).each do |tag|
      assert_instance_of Docker::Tag, tag 
    end
  end

  def test_images_returns_a_collection_of_repos
    Docker.images(:repository).each do |repo|
      assert_instance_of Docker::Repository, repo 
    end
  end
end

class ContainersTest < MiniTest::Unit::TestCase

  def self.before_suite
    TestHelper.setup_postgres_containers
    @@rails_server = Docker::Rails.run_server(TEST_APP_PATH)
    #@@rails_console = Docker::Rails.run_console(TEST_APP_PATH)
    #@@ruby_irb      = Docker::Ruby.run_irb(RUBY_APP_PATH)
    @@postgres     = Docker::Postgres.run('posty-5')
    @@gem_server   = Docker.run('ruby:2.1.2', '-d', 'gem server')

    @@all     = `docker ps -a`
    @@running = `docker ps`
    @@stopped = `docker ps -a | grep "Exited"`
    @@paused  = `docker ps | grep "(Paused)"`
  end

  def self.after_suite
    TestHelper.teardown_postgres_containers
    @@rails_server.remove! 
    #@@rails_console.remove!
    #@@ruby_irb.remove!   
    @@postgres.remove!   
    @@gem_server.remove!
  end

  def test_containers_is_not_empty
    refute_empty Docker.containers
  end

  def test_containers_returns_a_collection_of_containers
    Docker.containers.each do |container|
      assert_kind_of Docker::Container, container 
    end
  end

  def test_containers_returns_a_collection_of_all_containers
    Docker.containers.each do |container|
      assert_match /#{container.id}/, @@all 
    end
  end

  def test_containers_with_option_running_returns_only_running
    Docker.containers(:running).each do |container|
      assert_match /#{container.id}/, @@running
      refute_match /#{container.id}/, @@stopped
    end
  end

  def test_containers_with_option_stopped_returns_stopped_containers
    Docker.containers(:stopped).each do |container|
      refute_match /#{container.id}/, @@running
      assert_match /#{container.id}/, @@stopped
    end    
  end

  def test_containers_with_option_paused_returns_paused_containers
    Docker.containers(:paused).each do |container|
      assert_match /#{container.id}/, @@paused
    end
  end

  def test_running_not_equal_to_paused
    refute_equal Docker.containers(:paused),
      Docker.containers(:running)
  end

  def test_containers_accepts_the_all_argument
    assert Docker.containers(:all), 
      'Docker.containers(:all) should return something truthy'
  end

  def test_containers_raises_exception_for_other_arguments
    words = %w{ the red fox jumped over the redhat } 
    assert_raises(ArgumentError) do 
      Docker.containers(words.take.to_sym)
    end
  end

  def test_can_get_a_collection_of_containers_based_on_class
    klasses = [
      Docker::Rails::Server, Docker::Postgres, Docker::Container
    ]
    klasses.each do |klass|
      servers = Docker.find_containers(klass: klass)
      refute_empty servers
      servers.each do |server| 
        assert_instance_of klass, server
      end 
    end
  end
end
