require 'minitest/autorun'
require_relative '../lib/docker'

TEST_APP_PATH = '/home/john/projects/docker/rails/app'
RUBY_APP_PATH = '/home/john/projects/docker/ruby/app'

Docker.build(TEST_APP_PATH) if $0 =~ /app/

module TestHelper
  def self.remove_containers
    running = `docker ps`
    stopped = `docker ps -s`
    `docker stop rails-server-app` if running =~ /rails-server-app/
    `docker stop db`               if running =~ /\spostgres/
    `docker rm rails-server-app`   if stopped =~ /rails-server-app/
    `docker rm db`                 if stopped =~ /\spostgres/
  end

  def self.setup_postgres_containers 
    %w{ running stopped paused }.each do |name|
      `docker run -d --name #{name} postgres:9.3.5`
    end
    `docker pause paused`
    `docker stop stopped`
  end

  def self.teardown_postgres_containers
    `docker unpause paused`
    `docker rm -f running stopped paused`
  end

  def self.setup_posty(name)
    Docker.run('postgres:9.3.5', "-d --name #{name}")
  end

  def self.teardown_posty(name)
    `docker rm -f #{name}`
  end

  def self.assert_match_stdout(regexp, test_case)
    stdout = $stdout
    $stdout = StringIO.new
    yield
    $stdout.rewind
    test_case.assert_match regexp, $stdout.read
    $stdout = stdout
  end

  def self.assert_match_stderr(regexp, test_case)
    stderr = $stderr
    $stderr = StringIO.new
    yield
    $stderr.rewind
    test_case.assert_match regexp, $stderr.read
    $stderr = stderr
  end
end

module JohnsTest 
  class Unit < MiniTest::Unit
    def before_suites
    end

    def after_suites
    end

    def _run_suites(suites, type)
      begin
        before_suites
        super(suites, type)
      ensure
        after_suites
      end
    end

    def _run_suite(suite, type)
      begin
        suite.before_suite
        super(suite, type)
      ensure
        suite.after_suite
      end
    end
  end
end

module MiniTest
  class Spec
    def self.before_suite
    end

    def self.after_suite
    end
  end
end

MiniTest::Unit.runner = JohnsTest::Unit.new
